"use strict";
/* eslint-disable @typescript-eslint/ban-ts-comment,jest/expect-expect */
Object.defineProperty(exports, "__esModule", { value: true });
const tinyType_1 = require("../tinyType");
describe("Tiny type", () => {
    it("allows assigning when the tiny type matches", () => {
        // noinspection JSUnusedLocalSymbols - no compile errors means this behaves as intended
        const tinyType = asSomeString("the value");
    });
    it("allows obtaining the value of a tiny type", () => {
        const tinyType = asSomeString("the value");
        const value = valueOfSomeString(tinyType);
        expect(value).toStrictEqual("the value");
    });
    describe("comparing tiny types of the same type", () => {
        it("is equal when the underlying value is equal", () => {
            const value1 = asSomeString("the value");
            const value2 = asSomeString("the value");
            expect(value1 === value2).toStrictEqual(true);
        });
        it("is not equal when the underlying value is not equal", () => {
            const value1 = asSomeString("the value");
            const value2 = asSomeString("another value");
            expect(value1 === value2).toStrictEqual(false);
        });
        it("includes returns true if the value is a member of a set", () => {
            const set = [asSomeString("the value"), asSomeString("another value")];
            expect(set.includes(asSomeString("the value"))).toStrictEqual(true);
        });
        test("includes returns false if the value is not a member of a set", () => {
            const set = [asSomeString("the value"), asSomeString("another value")];
            expect(set.includes(asSomeString("yet another value"))).toStrictEqual(false);
        });
    });
    describe("compilation errors", () => {
        it("prevents assigning tiny types to primitives", () => {
            // @ts-expect-error
            // noinspection JSUnusedLocalSymbols
            const stringValue = asSomeString("the value");
        });
        it("prevents assigning primitives to tiny types", () => {
            // @ts-expect-error
            // noinspection JSUnusedLocalSymbols
            const tinyType = "the value";
        });
        it("prevents assigning objects to tiny types", () => {
            // @ts-expect-error
            // noinspection JSUnusedLocalSymbols
            const tinyType = {};
        });
        it("prevents assigning a tiny type to another tiny type", () => {
            // @ts-expect-error
            // noinspection JSUnusedLocalSymbols
            const tinyType = asSomeString("the value");
        });
        it("prevents comparing tiny types of different types", () => {
            const value1 = asSomeString("the value");
            const value2 = asSomeOtherString("the value");
            // @ts-expect-error
            // noinspection JSUnusedLocalSymbols
            const isEqual = value1 === value2;
        });
        it("prevents comparing tiny types with primitives", () => {
            const value1 = asSomeString("the value");
            // @ts-expect-error
            // noinspection JSUnusedLocalSymbols
            const isEqual = value1 === "the value";
        });
        it("prevents testing for set membership of different tiny types", () => {
            const set = [asSomeString("the value"), asSomeString("another value")];
            // @ts-expect-error
            set.includes(asSomeOtherString("the value"));
        });
        it("prevents testing for set membership of primitives", () => {
            const set = [asSomeString("the value"), asSomeString("another value")];
            // @ts-expect-error
            set.includes("the value");
        });
        it("prevents manually constructing the type", () => {
            const someSymbol = Symbol();
            // noinspection JSUnusedLocalSymbols
            const value = {
                // @ts-expect-error
                __someStringTinyType: someSymbol,
            };
            // noinspection JSUnusedLocalSymbols
            const value2 = {
                // @ts-expect-error
                __someStringTinyType: Symbol(),
            };
        });
    });
});
const asSomeString = (value) => (0, tinyType_1.convertToTinyType)(value);
const valueOfSomeString = (someString) => (0, tinyType_1.convertFromTinyType)(someString);
const asSomeOtherString = (value) => (0, tinyType_1.convertToTinyType)(value);
